/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/bovo-17.08.3/gui/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_gui__MainWindow_t {
    QByteArrayData data[20];
    char stringdata0[221];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_gui__MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_gui__MainWindow_t qt_meta_stringdata_gui__MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 15), // "gui::MainWindow"
QT_MOC_LITERAL(1, 16, 4), // "hint"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 11), // "slotNewGame"
QT_MOC_LITERAL(4, 34, 14), // "slotPlayerTurn"
QT_MOC_LITERAL(5, 49, 14), // "slotOposerTurn"
QT_MOC_LITERAL(6, 64, 12), // "slotGameOver"
QT_MOC_LITERAL(7, 77, 11), // "slotNewDemo"
QT_MOC_LITERAL(8, 89, 15), // "slotNewDemoWait"
QT_MOC_LITERAL(9, 105, 8), // "slotUndo"
QT_MOC_LITERAL(10, 114, 6), // "replay"
QT_MOC_LITERAL(11, 121, 11), // "changeSkill"
QT_MOC_LITERAL(12, 133, 11), // "changeTheme"
QT_MOC_LITERAL(13, 145, 14), // "reEnableReplay"
QT_MOC_LITERAL(14, 160, 10), // "enableUndo"
QT_MOC_LITERAL(15, 171, 11), // "disableUndo"
QT_MOC_LITERAL(16, 183, 11), // "setupThemes"
QT_MOC_LITERAL(17, 195, 4), // "save"
QT_MOC_LITERAL(18, 200, 12), // "setAnimation"
QT_MOC_LITERAL(19, 213, 7) // "enabled"

    },
    "gui::MainWindow\0hint\0\0slotNewGame\0"
    "slotPlayerTurn\0slotOposerTurn\0"
    "slotGameOver\0slotNewDemo\0slotNewDemoWait\0"
    "slotUndo\0replay\0changeSkill\0changeTheme\0"
    "reEnableReplay\0enableUndo\0disableUndo\0"
    "setupThemes\0save\0setAnimation\0enabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_gui__MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x0a /* Public */,
       3,    0,  100,    2, 0x0a /* Public */,
       4,    0,  101,    2, 0x0a /* Public */,
       5,    0,  102,    2, 0x0a /* Public */,
       6,    0,  103,    2, 0x0a /* Public */,
       7,    0,  104,    2, 0x0a /* Public */,
       8,    0,  105,    2, 0x0a /* Public */,
       9,    0,  106,    2, 0x0a /* Public */,
      10,    0,  107,    2, 0x0a /* Public */,
      11,    0,  108,    2, 0x0a /* Public */,
      12,    1,  109,    2, 0x0a /* Public */,
      13,    0,  112,    2, 0x0a /* Public */,
      14,    0,  113,    2, 0x0a /* Public */,
      15,    0,  114,    2, 0x0a /* Public */,
      16,    0,  115,    2, 0x0a /* Public */,
      17,    0,  116,    2, 0x0a /* Public */,
      18,    1,  117,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   19,

       0        // eod
};

void gui::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->hint(); break;
        case 1: _t->slotNewGame(); break;
        case 2: _t->slotPlayerTurn(); break;
        case 3: _t->slotOposerTurn(); break;
        case 4: _t->slotGameOver(); break;
        case 5: _t->slotNewDemo(); break;
        case 6: _t->slotNewDemoWait(); break;
        case 7: _t->slotUndo(); break;
        case 8: _t->replay(); break;
        case 9: _t->changeSkill(); break;
        case 10: _t->changeTheme((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->reEnableReplay(); break;
        case 12: _t->enableUndo(); break;
        case 13: _t->disableUndo(); break;
        case 14: _t->setupThemes(); break;
        case 15: _t->save(); break;
        case 16: _t->setAnimation((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject gui::MainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_gui__MainWindow.data,
      qt_meta_data_gui__MainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *gui::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *gui::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_gui__MainWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int gui::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
