/****************************************************************************
** Meta object code from reading C++ file 'scene.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/bovo-17.08.3/gui/scene.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scene.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_gui__Scene_t {
    QByteArrayData data[19];
    char stringdata0[184];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_gui__Scene_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_gui__Scene_t qt_meta_stringdata_gui__Scene = {
    {
QT_MOC_LITERAL(0, 0, 10), // "gui::Scene"
QT_MOC_LITERAL(1, 11, 4), // "move"
QT_MOC_LITERAL(2, 16, 0), // ""
QT_MOC_LITERAL(3, 17, 4), // "Move"
QT_MOC_LITERAL(4, 22, 11), // "updateBoard"
QT_MOC_LITERAL(5, 34, 14), // "slotPlayerTurn"
QT_MOC_LITERAL(6, 49, 14), // "slotOposerTurn"
QT_MOC_LITERAL(7, 64, 12), // "slotGameOver"
QT_MOC_LITERAL(8, 77, 11), // "QList<Move>"
QT_MOC_LITERAL(9, 89, 12), // "winningMoves"
QT_MOC_LITERAL(10, 102, 4), // "hint"
QT_MOC_LITERAL(11, 107, 11), // "hintTimeout"
QT_MOC_LITERAL(12, 119, 11), // "destroyHint"
QT_MOC_LITERAL(13, 131, 15), // "enableAnimation"
QT_MOC_LITERAL(14, 147, 7), // "enabled"
QT_MOC_LITERAL(15, 155, 6), // "setWin"
QT_MOC_LITERAL(16, 162, 6), // "replay"
QT_MOC_LITERAL(17, 169, 8), // "killMark"
QT_MOC_LITERAL(18, 178, 5) // "Mark*"

    },
    "gui::Scene\0move\0\0Move\0updateBoard\0"
    "slotPlayerTurn\0slotOposerTurn\0"
    "slotGameOver\0QList<Move>\0winningMoves\0"
    "hint\0hintTimeout\0destroyHint\0"
    "enableAnimation\0enabled\0setWin\0replay\0"
    "killMark\0Mark*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_gui__Scene[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   77,    2, 0x0a /* Public */,
       5,    0,   80,    2, 0x0a /* Public */,
       6,    0,   81,    2, 0x0a /* Public */,
       7,    1,   82,    2, 0x0a /* Public */,
      10,    1,   85,    2, 0x0a /* Public */,
      11,    0,   88,    2, 0x0a /* Public */,
      12,    0,   89,    2, 0x0a /* Public */,
      13,    1,   90,    2, 0x0a /* Public */,
      15,    0,   93,    2, 0x0a /* Public */,
      16,    0,   94,    2, 0x0a /* Public */,
      17,    1,   95,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    1,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 3,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,    2,

       0        // eod
};

void gui::Scene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Scene *_t = static_cast<Scene *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->move((*reinterpret_cast< const Move(*)>(_a[1]))); break;
        case 1: _t->updateBoard((*reinterpret_cast< const Move(*)>(_a[1]))); break;
        case 2: _t->slotPlayerTurn(); break;
        case 3: _t->slotOposerTurn(); break;
        case 4: _t->slotGameOver((*reinterpret_cast< const QList<Move>(*)>(_a[1]))); break;
        case 5: _t->hint((*reinterpret_cast< const Move(*)>(_a[1]))); break;
        case 6: _t->hintTimeout(); break;
        case 7: _t->destroyHint(); break;
        case 8: _t->enableAnimation((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->setWin(); break;
        case 10: _t->replay(); break;
        case 11: _t->killMark((*reinterpret_cast< Mark*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Scene::*_t)(const Move & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Scene::move)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject gui::Scene::staticMetaObject = {
    { &QGraphicsScene::staticMetaObject, qt_meta_stringdata_gui__Scene.data,
      qt_meta_data_gui__Scene,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *gui::Scene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *gui::Scene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_gui__Scene.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int gui::Scene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void gui::Scene::move(const Move & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
