/****************************************************************************
** Meta object code from reading C++ file 'game.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/bovo-17.08.3/game/game.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'game.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bovo__Game_t {
    QByteArrayData data[17];
    char stringdata0[156];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bovo__Game_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bovo__Game_t qt_meta_stringdata_bovo__Game = {
    {
QT_MOC_LITERAL(0, 0, 10), // "bovo::Game"
QT_MOC_LITERAL(1, 11, 8), // "gameOver"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 11), // "QList<Move>"
QT_MOC_LITERAL(4, 33, 5), // "moves"
QT_MOC_LITERAL(5, 39, 12), // "boardChanged"
QT_MOC_LITERAL(6, 52, 4), // "Move"
QT_MOC_LITERAL(7, 57, 4), // "move"
QT_MOC_LITERAL(8, 62, 10), // "playerTurn"
QT_MOC_LITERAL(9, 73, 10), // "oposerTurn"
QT_MOC_LITERAL(10, 84, 11), // "replayBegin"
QT_MOC_LITERAL(11, 96, 9), // "replayEnd"
QT_MOC_LITERAL(12, 106, 8), // "undoAble"
QT_MOC_LITERAL(13, 115, 11), // "undoNotAble"
QT_MOC_LITERAL(14, 127, 6), // "replay"
QT_MOC_LITERAL(15, 134, 10), // "undoLatest"
QT_MOC_LITERAL(16, 145, 10) // "replayNext"

    },
    "bovo::Game\0gameOver\0\0QList<Move>\0moves\0"
    "boardChanged\0Move\0move\0playerTurn\0"
    "oposerTurn\0replayBegin\0replayEnd\0"
    "undoAble\0undoNotAble\0replay\0undoLatest\0"
    "replayNext"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bovo__Game[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       5,    1,   77,    2, 0x06 /* Public */,
       8,    0,   80,    2, 0x06 /* Public */,
       9,    0,   81,    2, 0x06 /* Public */,
      10,    0,   82,    2, 0x06 /* Public */,
      11,    1,   83,    2, 0x06 /* Public */,
      12,    0,   86,    2, 0x06 /* Public */,
      13,    0,   87,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   88,    2, 0x0a /* Public */,
      14,    0,   91,    2, 0x0a /* Public */,
      15,    0,   92,    2, 0x0a /* Public */,
      16,    0,   93,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void bovo::Game::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Game *_t = static_cast<Game *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->gameOver((*reinterpret_cast< const QList<Move>(*)>(_a[1]))); break;
        case 1: _t->boardChanged((*reinterpret_cast< const Move(*)>(_a[1]))); break;
        case 2: _t->playerTurn(); break;
        case 3: _t->oposerTurn(); break;
        case 4: _t->replayBegin(); break;
        case 5: _t->replayEnd((*reinterpret_cast< const QList<Move>(*)>(_a[1]))); break;
        case 6: _t->undoAble(); break;
        case 7: _t->undoNotAble(); break;
        case 8: _t->move((*reinterpret_cast< const Move(*)>(_a[1]))); break;
        case 9: _t->replay(); break;
        case 10: _t->undoLatest(); break;
        case 11: _t->replayNext(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Game::*_t)(const QList<Move> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::gameOver)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Game::*_t)(const Move & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::boardChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::playerTurn)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::oposerTurn)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::replayBegin)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Game::*_t)(const QList<Move> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::replayEnd)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::undoAble)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::undoNotAble)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject bovo::Game::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_bovo__Game.data,
      qt_meta_data_bovo__Game,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bovo::Game::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bovo::Game::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bovo__Game.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int bovo::Game::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void bovo::Game::gameOver(const QList<Move> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void bovo::Game::boardChanged(const Move & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void bovo::Game::playerTurn()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void bovo::Game::oposerTurn()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void bovo::Game::replayBegin()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void bovo::Game::replayEnd(const QList<Move> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void bovo::Game::undoAble()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void bovo::Game::undoNotAble()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
